# KAE API LIBRARY
[![Build Status](https://travis-ci.org/kaecloud/kaelib.svg?branch=master)](https://travis-ci.org/kaecloud/kaelib)
[![](https://img.shields.io/pypi/v/kaelib.svg)](https://pypi.org/project/kaelib/)
[![](https://img.shields.io/badge/python-3.5,3.6-blue.svg)](https://pypi.org/project/kaelib/)

KAE api library for python
